@@ -135,12 +135,10 @@ first_empty_row (gint c)
 static gint
 get_n_human_players (void)
 {
-  if (p.level[PLAYER1] != LEVEL_HUMAN && p.level[PLAYER2] != LEVEL_HUMAN) {
+  if (p.level[PLAYER1] != LEVEL_HUMAN && p.level[PLAYER2] != LEVEL_HUMAN)
     return 0;
-  }
-  if (p.level[PLAYER1] != LEVEL_HUMAN || p.level[PLAYER2] != LEVEL_HUMAN) {
+  if (p.level[PLAYER1] != LEVEL_HUMAN || p.level[PLAYER2] != LEVEL_HUMAN)
     return 1;
-  }
   return 2;
 }
 
@@ -149,10 +147,8 @@ get_n_human_players (void)
 static gboolean
 is_player_human (void)
 {
-  if (player == PLAYER1) {
-    return p.level[PLAYER1] == LEVEL_HUMAN;
-  }
-  return p.level[PLAYER2] == LEVEL_HUMAN;
+  return player == PLAYER1 ? p.level[PLAYER1] == LEVEL_HUMAN
+                           : p.level[PLAYER2] == LEVEL_HUMAN;
 }
 
 
@@ -161,11 +157,7 @@ static void
 drop_marble (gint r, gint c)
 {
   gint tile;
-
-  if (player == PLAYER1)
-    tile = TILE_PLAYER1;
-  else
-    tile = TILE_PLAYER2;
+  tile = player == PLAYER1 ? TILE_PLAYER1 : TILE_PLAYER2;
 
   gboard[r][c] = tile;
   gfx_draw_tile (r, c);
@@ -180,11 +172,7 @@ static void
 drop (void)
 {
   gint tile;
-
-  if (player == PLAYER1)
-    tile = TILE_PLAYER1;
-  else
-    tile = TILE_PLAYER2;
+  tile = player == PLAYER1 ? TILE_PLAYER1 : TILE_PLAYER2;
 
   gboard[row][column] = TILE_CLEAR;
   gfx_draw_tile (row, column);
@@ -196,27 +184,6 @@ drop (void)
 
 
 
-static void
-move_cursor (gint c)
-{
-  gboard[0][column] = TILE_CLEAR;
-  gfx_draw_tile (0, column);
-
-  column = c;
-
-  if (player == PLAYER1)
-    gboard[0][c] = TILE_PLAYER1;
-  else
-    gboard[0][c] = TILE_PLAYER2;
-
-  gfx_draw_tile (0, c);
-
-  column = column_moveto = c;
-  row = row_dropto = 0;
-}
-
-
-
 static void
 move (gint c)
 {
@@ -224,15 +191,19 @@ move (gint c)
   gfx_draw_tile (0, column);
 
   column = c;
-
-  if (player == PLAYER1)
-    gboard[0][c] = TILE_PLAYER1;
-  else
-    gboard[0][c] = TILE_PLAYER2;
+  gboard[0][c] = player == PLAYER1 ? TILE_PLAYER1 : TILE_PLAYER2;
 
   gfx_draw_tile (0, c);
 }
 
+static void
+move_cursor (gint c)
+{
+  move (c);
+  column = column_moveto = c;
+  row = row_dropto = 0;
+}
+
 
 
 static void
@@ -285,10 +256,10 @@ on_animate (gint c)
     } else {
       timeout = 0;
       if (anim == ANIM_MOVE) {
-	anim = ANIM_NONE;
-	process_move2 (c);
+        anim = ANIM_NONE;
+        process_move2 (c);
       } else {
-	anim = ANIM_NONE;
+        anim = ANIM_NONE;
       }
       return FALSE;
     }
@@ -304,10 +275,8 @@ on_animate (gint c)
     }
     break;
   case ANIM_BLINK:
-    if (blink_on)
-      draw_line (blink_r1, blink_c1, blink_r2, blink_c2, blink_t);
-    else
-      draw_line (blink_r1, blink_c1, blink_r2, blink_c2, TILE_CLEAR);
+      draw_line (blink_r1, blink_c1, blink_r2, blink_c2, blink_on ? blink_t
+                                                                  : TILE_CLEAR);
     blink_n--;
     if (blink_n <= 0 && blink_on) {
       anim = ANIM_NONE;
@@ -381,7 +350,7 @@ game_init (void)
   score[PLAYER2] = 0;
   score[NOBODY] = 0;
 
-  who_starts = PLAYER2;		/* This gets reversed immediately. */
+  who_starts = PLAYER2;     /* This gets reversed immediately. */
 
   clear_board ();
 }
@@ -415,11 +384,8 @@ game_reset (void)
   gameover = FALSE;
   prompt_player ();
   if (!is_player_human ()) {
-    if (player == PLAYER1) {
-      vstr[0] = vlevel[p.level[PLAYER1]];
-    } else {
-      vstr[0] = vlevel[p.level[PLAYER2]];
-    }
+    vstr[0] = player == PLAYER1 ? vlevel[p.level[PLAYER1]]
+                                : vlevel[p.level[PLAYER2]];
     game_process_move (playgame (vstr) - 1);
   }
 }
@@ -504,11 +470,10 @@ prompt_player (void)
   }
 
   if (gameover && winner == NOBODY) {
-    if (score[NOBODY] == 0) {
+    if (score[NOBODY] == 0)
       set_status_message (NULL);
-    } else {
+    else
       set_status_message (_("It’s a draw!"));
-    }
     return;
   }
 
@@ -516,36 +481,30 @@ prompt_player (void)
   case 1:
     if (human) {
       if (gameover)
-	set_status_message (_("You win!"));
+        set_status_message (_("You win!"));
       else
-	set_status_message (_("Your Turn"));
+        set_status_message (_("Your Turn"));
     } else {
       if (gameover)
-	set_status_message (_("I win!"));
+        set_status_message (_("I win!"));
       else
-	set_status_message (_("I’m Thinking…"));
+        set_status_message (_("I’m Thinking…"));
     }
     break;
   case 2:
   case 0:
 
     if (gameover) {
-	if (player == PLAYER1)
-	  who = theme_get_player_win (PLAYER1);
-	else
-	  who = theme_get_player_win (PLAYER2);
-	str = g_strdup_printf ("%s", _(who));
-      }
-    else if (player_active) {
+      who = player == PLAYER1 ? theme_get_player_win (PLAYER1)
+                              : theme_get_player_win (PLAYER2);
+      str = g_strdup_printf ("%s", _(who));
+    } else if (player_active) {
       set_status_message (_("Your Turn"));
       return;
-
     } else {
-	if (player == PLAYER1)
-	  who = theme_get_player_turn (PLAYER1);
-	else
-	  who = theme_get_player_turn (PLAYER2);
-        str = g_strdup_printf ("%s", _(who));
+      who = player == PLAYER1 ? theme_get_player_turn (PLAYER1)
+                              : theme_get_player_turn (PLAYER2);
+      str = g_strdup_printf ("%s", _(who));
     }
 
     set_status_message (str);
@@ -646,9 +605,9 @@ on_game_hint (GSimpleAction *action, GVariant *parameter, gpointer data)
   g_free (s);
 
   if (moves <= 0 || (moves == 1 && is_player_human ()))
-	g_simple_action_set_enabled (G_SIMPLE_ACTION (undo_action), FALSE);
+    g_simple_action_set_enabled (G_SIMPLE_ACTION (undo_action), FALSE);
   else
-	g_simple_action_set_enabled (G_SIMPLE_ACTION (undo_action), TRUE);
+    g_simple_action_set_enabled (G_SIMPLE_ACTION (undo_action), TRUE);
 }
 
 void
@@ -677,9 +636,9 @@ scorebox_update (void)
     }
   } else {
     gtk_label_set_text (GTK_LABEL (label_name[PLAYER1]),
-			_(theme_get_player (PLAYER1)));
+                        _(theme_get_player (PLAYER1)));
     gtk_label_set_text (GTK_LABEL (label_name[PLAYER2]),
-			_(theme_get_player (PLAYER2)));
+                        _(theme_get_player (PLAYER2)));
   }
 
   s = g_strdup_printf ("%d", score[PLAYER1]);
@@ -719,16 +678,16 @@ on_game_scores (GSimpleAction *action, GVariant *parameter, gpointer data)
   }
 
   scorebox = gtk_dialog_new_with_buttons (_("Scores"),
-					  GTK_WINDOW (window),
-					  GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_USE_HEADER_BAR,
-					  NULL);
+                                          GTK_WINDOW (window),
+                                          GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_USE_HEADER_BAR,
+                                          NULL);
 
   gtk_window_set_resizable (GTK_WINDOW (scorebox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (scorebox), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (scorebox))), 2);
 
   g_signal_connect (scorebox, "destroy",
-		    G_CALLBACK (gtk_widget_destroyed), &scorebox);
+                    G_CALLBACK (gtk_widget_destroyed), &scorebox);
 
   grid = gtk_grid_new ();
   gtk_widget_set_halign (grid, GTK_ALIGN_CENTER);
@@ -737,7 +696,7 @@ on_game_scores (GSimpleAction *action, GVariant *parameter, gpointer data)
   gtk_container_set_border_width (GTK_CONTAINER (grid), 5);
 
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (scorebox))),
-		      grid, TRUE, TRUE, 0);
+                      grid, TRUE, TRUE, 0);
 
   grid2 = gtk_grid_new ();
   gtk_container_add (GTK_CONTAINER (grid), grid2);
@@ -768,7 +727,7 @@ on_game_scores (GSimpleAction *action, GVariant *parameter, gpointer data)
   gtk_misc_set_alignment (GTK_MISC (label_score[NOBODY]), 1, 0.5);
 
   g_signal_connect (GTK_DIALOG (scorebox), "response",
-		    G_CALLBACK (on_dialog_close), NULL);
+                    G_CALLBACK (on_dialog_close), NULL);
 
   gtk_widget_show_all (scorebox);
 
@@ -778,20 +737,13 @@ on_game_scores (GSimpleAction *action, GVariant *parameter, gpointer data)
 static void
 on_help_about (GSimpleAction *action, GVariant *parameter, gpointer data)
 {
-  const gchar *authors[] = { "Four-in-a-row:",
-    "  Tim Musson <trmusson@ihug.co.nz>",
-    "  David Neary <bolsh@gimp.org>",
-    "",
-    "Velena Engine V1.07:",
-    "  AI engine written by Giuliano Bertoletti",
-    "  Based on the knowledged approach of Victor Allis",
-    "  Copyright (C) 1996-97 ",
-    "  Giuliano Bertoletti and GBE 32241 Software PR.",
+  const gchar *authors[] = {"Tim Musson <trmusson@ihug.co.nz>",
+    "David Neary <bolsh@gimp.org>",
+    "Nikhar Agrawal <nikharagrawal2006@gmail.com>",
     NULL
   };
 
   const gchar *artists[] = { "Alan Horkan",
-    "Tim Musson",
     "Anatol Drlicek",
     "Based on the Faenza icon theme by Matthieu James",
     NULL
@@ -802,18 +754,18 @@ on_help_about (GSimpleAction *action, GVariant *parameter, gpointer data)
   };
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-			 "name", _(APPNAME_LONG),
-			 "version", VERSION,
-			 "copyright",
-			 "Copyright © 1999–2008, Tim Musson and David Neary",
-			 "license-type", GTK_LICENSE_GPL_2_0, "comments",
-		         _("Connect four in a row to win.\n\nFour-in-a-row is a part of GNOME Games."),
-			 "authors", authors, "documenters", documenters,
-			 "artists", artists, "translator-credits",
-			 _("translator-credits"),
-			 "logo-icon-name", "four-in-a-row",
-			 "website", "https://wiki.gnome.org/Apps/Four-in-a-row",
-			 NULL);
+                         "name", _(APPNAME_LONG),
+                         "version", VERSION,
+                         "copyright",
+                         "Copyright © 1999–2008 Tim Musson and David Neary\nCopyright © 2014 Michael Catanzaro",
+                         "license-type", GTK_LICENSE_GPL_2_0, "comments",
+                         _("Connect four in a row to win."),
+                         "authors", authors, "documenters", documenters,
+                         "artists", artists, "translator-credits",
+                         _("translator-credits"),
+                         "logo-icon-name", "four-in-a-row",
+                         "website", "https://wiki.gnome.org/Apps/Four-in-a-row",
+                         NULL);
 }
 
 
@@ -838,8 +790,7 @@ on_settings_preferences (GSimpleAction *action, GVariant *parameter, gpointer us
 
 
 static gboolean
-is_hline_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
-	     gint * c2)
+is_hline_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2, gint * c2)
 {
   *r1 = *r2 = r;
   *c1 = *c2 = c;
@@ -855,8 +806,7 @@ is_hline_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
 
 
 static gboolean
-is_vline_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
-	     gint * c2)
+is_vline_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2, gint * c2)
 {
   *r1 = *r2 = r;
   *c1 = *c2 = c;
@@ -872,8 +822,7 @@ is_vline_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
 
 
 static gboolean
-is_dline1_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
-	      gint * c2)
+is_dline1_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2, gint * c2)
 {
   /* upper left to lower right */
   *r1 = *r2 = r;
@@ -894,8 +843,7 @@ is_dline1_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
 
 
 static gboolean
-is_dline2_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2,
-	      gint * c2)
+is_dline2_at (PlayerID p, gint r, gint c, gint * r1, gint * c1, gint * r2, gint * c2)
 {
   /* upper right to lower left */
   *r1 = *r2 = r;
@@ -937,8 +885,7 @@ blink_winner (gint n)
     return;
 
   blink_t = winner;
-  if (is_hline_at
-      (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
+  if (is_hline_at (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
     anim = ANIM_BLINK;
     blink_on = FALSE;
     blink_n = n;
@@ -947,8 +894,7 @@ blink_winner (gint n)
       gtk_main_iteration ();
   }
 
-  if (is_vline_at
-      (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
+  if (is_vline_at (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
     anim = ANIM_BLINK;
     blink_on = FALSE;
     blink_n = n;
@@ -957,8 +903,7 @@ blink_winner (gint n)
       gtk_main_iteration ();
   }
 
-  if (is_dline1_at
-      (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
+  if (is_dline1_at (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
     anim = ANIM_BLINK;
     blink_on = FALSE;
     blink_n = n;
@@ -967,8 +912,7 @@ blink_winner (gint n)
       gtk_main_iteration ();
   }
 
-  if (is_dline2_at
-      (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
+  if (is_dline2_at (winner, row, column, &blink_r1, &blink_c1, &blink_r2, &blink_c2)) {
     anim = ANIM_BLINK;
     blink_on = FALSE;
     blink_n = n;
@@ -988,11 +932,7 @@ check_game_state (void)
     winner = player;
     switch (get_n_human_players ()) {
     case 1:
-      if (is_player_human ()) {
-	play_sound (SOUND_YOU_WIN);
-      } else {
-	play_sound (SOUND_I_WIN);
-      }
+      play_sound (is_player_human () ? SOUND_YOU_WIN : SOUND_I_WIN);
       break;
     case 0:
     case 2:
@@ -1024,16 +964,13 @@ void
 process_move (gint c)
 {
   if (timeout) {
-    g_timeout_add (SPEED_DROP,
-	           (GSourceFunc) next_move, GINT_TO_POINTER (c));
+    g_timeout_add (SPEED_DROP, (GSourceFunc) next_move, GINT_TO_POINTER (c));
     return;
-
   }
 
   column_moveto = c;
   anim = ANIM_MOVE;
-  timeout = g_timeout_add (SPEED_MOVE,
-                           (GSourceFunc) on_animate, GINT_TO_POINTER (c));
+  timeout = g_timeout_add (SPEED_MOVE, (GSourceFunc) on_animate, GINT_TO_POINTER (c));
 }
 
 static void
@@ -1046,9 +983,7 @@ process_move2 (gint c)
     row = 0;
     row_dropto = r;
     anim = ANIM_DROP;
-    timeout = g_timeout_add (SPEED_DROP,
-                             (GSourceFunc) on_animate,
-                             GINT_TO_POINTER (c));
+    timeout = g_timeout_add (SPEED_DROP, (GSourceFunc) on_animate, GINT_TO_POINTER (c));
   } else {
     play_sound (SOUND_COLUMN_FULL);
   }
@@ -1071,16 +1006,12 @@ process_move3 (gint c)
   } else {
     swap_player ();
     if (!is_player_human ()) {
-      if (player == PLAYER1) {
-	vstr[0] = vlevel[p.level[PLAYER1]];
-      } else {
-	vstr[0] = vlevel[p.level[PLAYER2]];
-      }
+      vstr[0] = player == PLAYER1 ? vlevel[p.level[PLAYER1]]
+                                  : vlevel[p.level[PLAYER2]];
       c = playgame (vstr) - 1;
       if (c < 0)
-	gameover = TRUE;
-      g_timeout_add (SPEED_DROP,
-                     (GSourceFunc) next_move, GINT_TO_POINTER (c));
+        gameover = TRUE;
+      g_timeout_add (SPEED_DROP, (GSourceFunc) next_move, GINT_TO_POINTER (c));
     }
   }
 }
@@ -1157,37 +1088,34 @@ static const GActionEntry app_entries[] = {
   {"about", on_help_about, NULL, NULL, NULL}
 };
 
-static gboolean
-create_app (void)
+static void
+create_app (GApplication *app, gpointer user_data)
 {
   GtkWidget *frame;
-  GtkWidget *hbox, *vbox;
-  GtkWidget *image;
-  GtkWidget *new_game_button;
-  GtkWidget *undo_button;
-  GtkWidget *hint_button;
   GMenu *app_menu, *section;
 
-  window = gtk_application_window_new (application);
-  gtk_window_set_application (GTK_WINDOW (window), application);
-  gtk_window_set_title (GTK_WINDOW (window), _(APPNAME_LONG));
-  gtk_container_set_border_width (GTK_CONTAINER (window), 25);
-  gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
+  GtkBuilder *builder = NULL;
+  GtkCssProvider *css_provider = NULL;
+  GError *error = NULL;
+
   gtk_window_set_default_icon_name ("four-in-a-row");
 
-  headerbar = gtk_header_bar_new ();
-  gtk_header_bar_set_title (GTK_HEADER_BAR (headerbar), _("Four-in-a-row"));
-  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (headerbar), TRUE);
-  gtk_widget_show (headerbar);
-  gtk_window_set_titlebar (GTK_WINDOW (window), headerbar);
+  css_provider = gtk_css_provider_get_default ();
+  gtk_css_provider_load_from_data (css_provider, "GtkButtonBox{-GtkButtonBox-child-internal-pad-x:0;}\0", -1, &error);
+  if (G_UNLIKELY (error != NULL)) {
+      fprintf (stderr, "Could not load UI: %s\n", error->message);
+      g_clear_error (&error);
+      return;
+  }
+  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), css_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
-  undo_button = gtk_button_new_from_icon_name ("edit-undo-symbolic", GTK_ICON_SIZE_BUTTON);
-  gtk_widget_set_valign (undo_button, GTK_ALIGN_CENTER);
-  gtk_widget_set_halign (undo_button, GTK_ALIGN_CENTER);
-  gtk_actionable_set_action_name (GTK_ACTIONABLE (undo_button), "app.undo-move");
-  gtk_widget_set_tooltip_text (undo_button, _("Undo your most recent move"));
-  gtk_widget_show (undo_button);
-  gtk_header_bar_pack_start (GTK_HEADER_BAR (headerbar), undo_button);
+  builder = gtk_builder_new_from_file (DATA_DIRECTORY "/four-in-a-row.ui");
+
+  window = gtk_builder_get_object (builder, "fiar-window");
+  gtk_window_set_application (GTK_WINDOW (window), application);
+  gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);     // TODO save size & state
+
+  headerbar = gtk_builder_get_object (builder, "headerbar");
 
   g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries, G_N_ELEMENTS (app_entries), application);
   gtk_application_add_accelerator (application, "<Primary>n", "app.new-game", NULL);
@@ -1214,70 +1142,40 @@ create_app (void)
 
   gtk_application_set_app_menu (GTK_APPLICATION (application), G_MENU_MODEL (app_menu));
 
-  frame = gtk_aspect_frame_new (NULL, 0.5, 0.5, 1.45, FALSE);
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-  gtk_container_add (GTK_CONTAINER (window), frame);
-
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 25);
-  gtk_container_add (GTK_CONTAINER (frame), hbox);
+  frame = gtk_builder_get_object (builder, "frame");
 
   drawarea = gtk_drawing_area_new ();
   /* set a min size to avoid pathological behavior of gtk when scaling down */
   gtk_widget_set_size_request (drawarea, 350, 350);
-  gtk_box_pack_start (GTK_BOX (hbox), drawarea, TRUE, TRUE, 0);
+  gtk_widget_set_halign (drawarea, GTK_ALIGN_FILL);
+  gtk_widget_set_valign (drawarea, GTK_ALIGN_FILL);
+  gtk_container_add (GTK_CONTAINER (frame), drawarea);
 
   gtk_widget_set_events (drawarea, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
   g_signal_connect (G_OBJECT (drawarea), "configure_event",
-		    G_CALLBACK (on_drawarea_resize), NULL);
+                    G_CALLBACK (on_drawarea_resize), NULL);
   g_signal_connect (G_OBJECT (drawarea), "draw",
-		    G_CALLBACK (on_drawarea_draw), NULL);
+                    G_CALLBACK (on_drawarea_draw), NULL);
   g_signal_connect (G_OBJECT (drawarea), "button_press_event",
-		    G_CALLBACK (on_button_press), NULL);
+                    G_CALLBACK (on_button_press), NULL);
   g_signal_connect (G_OBJECT (window), "key_press_event",
-		    G_CALLBACK (on_key_press), NULL);
+                    G_CALLBACK (on_key_press), NULL);
 
   /* We do our own double-buffering. */
   gtk_widget_set_double_buffered (GTK_WIDGET (drawarea), FALSE);
 
-  vbox = gtk_button_box_new (GTK_ORIENTATION_VERTICAL);
-  gtk_box_set_spacing (GTK_BOX (vbox), 6);
-  gtk_widget_set_valign (vbox, GTK_ALIGN_END);
-  gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, TRUE, 0);
-
-  hint_button = gtk_button_new ();
-  gtk_button_set_label (GTK_BUTTON (hint_button), _("_Hint"));
-  gtk_button_set_use_underline (GTK_BUTTON (hint_button), TRUE);
-  gtk_widget_set_valign (hint_button, GTK_ALIGN_CENTER);
-  gtk_widget_set_halign (hint_button, GTK_ALIGN_FILL);
-  gtk_widget_set_size_request (hint_button, 120, 60);
-  gtk_actionable_set_action_name (GTK_ACTIONABLE (hint_button), "app.hint");
-  gtk_widget_set_tooltip_text (hint_button, _("Receive a hint for your next move"));
-  gtk_box_pack_end (GTK_BOX (vbox), hint_button, FALSE, FALSE, 0);
-
-  new_game_button = gtk_button_new ();
-  gtk_button_set_label (GTK_BUTTON (new_game_button), _("_Start Over"));
-  gtk_button_set_use_underline (GTK_BUTTON (new_game_button), TRUE);
-  gtk_widget_set_valign (new_game_button, GTK_ALIGN_CENTER);
-  gtk_widget_set_halign (new_game_button, GTK_ALIGN_FILL);
-  gtk_widget_set_size_request (new_game_button, 120, 60);
-  gtk_actionable_set_action_name (GTK_ACTIONABLE (new_game_button), "app.new-game");
-  gtk_widget_set_tooltip_text (new_game_button, _("Start a new game"));
-  gtk_box_pack_end (GTK_BOX (vbox), new_game_button, FALSE, FALSE, 0);
-
   g_simple_action_set_enabled (G_SIMPLE_ACTION (hint_action), FALSE);
   g_simple_action_set_enabled (G_SIMPLE_ACTION (undo_action), FALSE);
-
-  return TRUE;
 }
 
 static void
-activate (void)
+activate (GApplication *app, gpointer user_data)
 {
   if (!gtk_widget_is_visible (window)) {
     gtk_widget_show_all (window);
     gfx_refresh_pixmaps ();
     gfx_draw_all ();
-    scorebox_update ();		/* update visible player descriptions */
+    scorebox_update ();       /* update visible player descriptions */
     prompt_player ();
     game_reset ();
   }
@@ -1318,9 +1216,8 @@ main (int argc, char *argv[])
   game_init ();
 
   /* init gfx */
-  if (!gfx_load_pixmaps ()) {
+  if (!gfx_load_pixmaps ())
     exit (1);
-  }
 
   app_retval = g_application_run (G_APPLICATION (application), argc, argv);
 
